NeumorphicBoxShape class

Define a Neumorphic container box shape

Properties

customShapePathProvider → NeumorphicPathProvider
final
hashCode → int
The hash code for this object.
no setterinherited
isBeveled → bool
no setter
isCircle → bool
no setter
isCustomPath → bool
no setter
isRect → bool
no setter
isRoundRect → bool
no setter
isStadium → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited