NeumorphicCheckbox class

A Neumorphic Checkbox

takes a NeumorphicCheckboxStyle as style takes the current checked state as value

notifies the parent when user interact with this widget with onChanged

 bool check1 = false;
 bool check2 = false;
 bool check3 = false;

 Widget _buildChecks() {
   return Row(
     children: <Widget>[

       NeumorphicCheckbox(
         value: check1,
         onChanged: (value) {
           setState(() {
             check1 = value;
           });
         },
       ),

       NeumorphicCheckbox(
         value: check2,
         onChanged: (value) {
           setState(() {
             check2 = value;
           });
         },
       ),

       NeumorphicCheckbox(
         value: check3,
         onChanged: (value) {
           setState(() {
             check3 = value;
           });
         },
       ),

     ],
   );
 }
Inheritance
Annotations

Constructors

NeumorphicCheckbox({NeumorphicCheckboxStyle style = const NeumorphicCheckboxStyle(), required bool value, required NeumorphicCheckboxListener onChanged, Curve curve = Neumorphic.DEFAULT_CURVE, Duration duration = Neumorphic.DEFAULT_DURATION, EdgeInsets padding = const EdgeInsets.symmetric(horizontal: 16.0, vertical: 12.0), EdgeInsets margin = const EdgeInsets.all(0), dynamic isEnabled = true})

Properties

curve → Curve
final
duration → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
isEnabled → dynamic
final
isSelected → bool
no setter
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin → EdgeInsets
final
onChanged → NeumorphicCheckboxListener
final
padding → EdgeInsets
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → NeumorphicCheckboxStyle
final
value → bool
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited