NeumorphicCheckboxStyle class

A Style used to customize a NeumorphicCheckbox

selectedDepth : the depth when checked unselectedDepth : the depth when unchecked (default : theme.depth) selectedColor : the color when checked (default: theme.accent)

Constructors

NeumorphicCheckboxStyle({double? selectedDepth, NeumorphicBorder border = const NeumorphicBorder.none(), Color? selectedColor, double? unselectedDepth, bool? disableDepth, LightSource? lightSource, Color? disabledColor, NeumorphicBoxShape? boxShape, double? selectedIntensity = 1, double unselectedIntensity = 0.7})
const

Properties

border → NeumorphicBorder
final
boxShape → NeumorphicBoxShape?
final
disabledColor → Color?
final
disableDepth → bool?
final
hashCode → int
The hash code for this object.
no setteroverride
lightSource → LightSource?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedColor → Color?
final
selectedDepth → double?
final
selectedIntensity → double?
final
unselectedDepth → double?
final
unselectedIntensity → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override