NeumorphicStyle class

Constructors

NeumorphicStyle({NeumorphicShape shape = _defaultShape, LightSource lightSource = LightSource.topLeft, NeumorphicBorder border = const NeumorphicBorder.none(), Color? color, NeumorphicBoxShape? boxShape, Color? shadowLightColor, Color? shadowDarkColor, Color? shadowLightColorEmboss, Color? shadowDarkColorEmboss, double? depth, double? intensity, double surfaceIntensity = 0.25, bool? disableDepth, bool oppositeShadowLightSource = false})
const

Properties

border → NeumorphicBorder
final
boxShape → NeumorphicBoxShape?
final
color → Color?
final
depth → double?
no setter
disableDepth → bool?
final
hashCode → int
The hash code for this object.
no setteroverride
intensity → double?
no setter
lightSource → LightSource
final
oppositeShadowLightSource → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadowDarkColor → Color?
final
shadowDarkColorEmboss → Color?
final
shadowLightColor → Color?
final
shadowLightColorEmboss → Color?
final
shape → NeumorphicShape
final
surfaceIntensity → double
no setter
theme → NeumorphicThemeData?
final

Methods

applyDisableDepth() → NeumorphicStyle
copyWith({Color? color, NeumorphicBorder? border, NeumorphicBoxShape? boxShape, Color? shadowLightColor, Color? shadowDarkColor, Color? shadowLightColorEmboss, Color? shadowDarkColorEmboss, double? depth, double? intensity, double? surfaceIntensity, LightSource? lightSource, bool? disableDepth, double? borderRadius, bool? oppositeShadowLightSource, NeumorphicShape? shape}) → NeumorphicStyle
copyWithThemeIfNull(NeumorphicThemeData theme) → NeumorphicStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override