NeumorphicSwitchStyle class

A style to customize the NeumorphicSwitch

you can define the track : activeTrackColor, inactiveTrackColor, trackDepth

you can define the thumb : activeTrackColor, inactiveTrackColor, thumbDepth and thumbShape @see NeumorphicShape

Constructors

NeumorphicSwitchStyle({double? trackDepth, NeumorphicShape? thumbShape = NeumorphicShape.concave, Color? activeTrackColor, Color? inactiveTrackColor, Color? activeThumbColor, Color? inactiveThumbColor, double? thumbDepth, LightSource? lightSource, bool disableDepth = false, NeumorphicBorder thumbBorder = const NeumorphicBorder.none(), NeumorphicBorder trackBorder = const NeumorphicBorder.none()})
const

Properties

activeThumbColor → Color?
final
activeTrackColor → Color?
final
disableDepth → bool
final
hashCode → int
The hash code for this object.
no setteroverride
inactiveThumbColor → Color?
final
inactiveTrackColor → Color?
final
lightSource → LightSource?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbBorder → NeumorphicBorder
final
thumbDepth → double?
final
thumbShape → NeumorphicShape?
final
trackBorder → NeumorphicBorder
final
trackDepth → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override