NeumorphicTextStyle class

Constructors

NeumorphicTextStyle({bool inherit = true, double? fontSize, FontWeight? fontWeight, FontStyle? fontStyle, double? letterSpacing, double? wordSpacing, TextBaseline? textBaseline, double? height, Locale? locale, List<FontFeature>? fontFeatures, TextDecoration? decoration, String? debugLabel, String? fontFamily, List<String>? fontFamilyFallback, String? package})
Creates a text style.

Properties

debugLabel → String?
final
decoration → TextDecoration?
final
fontFamily → String?
final
fontFamilyFallback → List<String>?
final
fontFeatures → List<FontFeature>?
final
fontSize → double?
final
fontStyle → FontStyle?
final
fontWeight → FontWeight?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
inherit → bool
final
letterSpacing → double?
final
locale → Locale?
final
package → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textBaseline → TextBaseline?
final
textStyle → TextStyle
no setter
wordSpacing → double?
final

Methods

copyWith({bool? inherit, String? fontFamily, List<String>? fontFamilyFallback, double? fontSize, FontWeight? fontWeight, FontStyle? fontStyle, double? letterSpacing, double? wordSpacing, TextBaseline? textBaseline, double? height, Locale? locale, List<FontFeature>? fontFeatures, String? debugLabel}) → NeumorphicTextStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited