NeumorphicToggleStyle class

Constructors

NeumorphicToggleStyle({double? depth, bool animateOpacity = true, Color? backgroundColor, LightSource? lightSource, BorderRadius borderRadius = const BorderRadius.all(Radius.circular(12)), bool? disableDepth, NeumorphicBorder border = const NeumorphicBorder.none()})
const

Properties

animateOpacity → bool
final
backgroundColor → Color?
final
border → NeumorphicBorder
final
borderRadius → BorderRadius
final
depth → double?
final
disableDepth → bool?
final
hashCode → int
The hash code for this object.
no setteroverride
lightSource → LightSource?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override