ProgressStyle class

A style to customize the NeumorphicProgress

the gradient will use accent and variant

the gradient shape will be a roundrect, using borderRadius

you can define a custom depth for the roundrect

you can update the gradient orientation using progressGradientStart & progressGradientEnd

Constructors

ProgressStyle({double depth = 0, bool disableDepth = false, BorderRadius borderRadius = const BorderRadius.all(Radius.circular(10.0)), BorderRadius? gradientBorderRadius, Color? accent, LightSource? lightSource, AlignmentGeometry? progressGradientStart, AlignmentGeometry? progressGradientEnd, Color? variant, NeumorphicBorder border = const NeumorphicBorder.none()})
const

Properties

accent → Color?
final
border → NeumorphicBorder
final
borderRadius → BorderRadius
final
depth → double
final
disableDepth → bool
final
gradientBorderRadius → BorderRadius?
final
hashCode → int
The hash code for this object.
no setteroverride
lightSource → LightSource?
final
progressGradientEnd → AlignmentGeometry?
final
progressGradientStart → AlignmentGeometry?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
variant → Color?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override