SliderStyle class

A style to customize the NeumorphicSlider

the gradient will use accent and variant

the gradient shape will be a roundrect, using borderRadius

you can define a custom depth for the roundrect

Annotations

Constructors

SliderStyle({double depth = 0, bool disableDepth = false, BorderRadius borderRadius = const BorderRadius.all(Radius.circular(10)), Color? accent, LightSource? lightSource, Color? variant, NeumorphicBorder border = const NeumorphicBorder.none(), NeumorphicBorder thumbBorder = const NeumorphicBorder.none()})
const

Properties

accent → Color?
final
border → NeumorphicBorder
final
borderRadius → BorderRadius
final
depth → double
final
disableDepth → bool
final
hashCode → int
The hash code for this object.
no setteroverride
lightSource → LightSource?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbBorder → NeumorphicBorder
final
variant → Color?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override