ThemeWrapper class

A immutable contained by the NeumorhicTheme That will save the current definition of the theme It will be accessible to the childs widgets by an InheritedWidget

Constructors

ThemeWrapper({required NeumorphicThemeData theme, NeumorphicThemeData? darkTheme, ThemeMode themeMode = ThemeMode.system})
const

Properties

current → NeumorphicThemeData?
no setter
darkTheme → NeumorphicThemeData?
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
theme → NeumorphicThemeData
final
themeMode → ThemeMode
final
useDark → bool
no setter

Methods

copyWith({NeumorphicThemeData? theme, NeumorphicThemeData? darkTheme, ThemeMode? currentTheme}) → ThemeWrapper
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override